/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03088
 |           ALCOHOL AND DRUG SERVICES STUDY (ADSS), 1996-1999:
 |                            [UNITED STATES]
 |        (DATASET 0004: PHASE II IN-TREATMENT METHADONE ABSTRACT)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03088-0004-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Alcohol and Drug Services Study (ADSS), 1996-1999: [United States], Phase II In-Treatment Methadone Abstract"

#delimit ;
label define CLTYPE    1 "NONMETHADONE DISCHARGE" 2 "METHADONE DISCHARGE"
                       3 "IN-TREATMENT METHADONE" ;
label define COMIN     -5 "MISSING" ;
label define A6        -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "NON-HOSPITAL RESIDENTIAL"
                       2 "OUTPATIENT"
                       3 "OTHER (IF COMBINATIONS, SPECIFY TYPE AND"
                       4 "RESIDENTIAL AND OUTPATIENT" 5 "SPLIT" ;
label define A6A1      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A6A2      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A6A3      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A7        -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A9        -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "OTHER TREATMENT REFERRED"
                       2 "CRIMINAL JUSTICE SYSTEM"
                       3 "SELF-REFERRED/VOLUNTARY" 4 "FAMILY"
                       5 "FRIEND REFERRED" 6 "EMPLOYER"
                       7 "HEALTH CARE OR MENTAL HEALTH PROVIDES"
                       8 "WELFARE OFFICE OR OTHER SOCIAL SERVICE A"
                       9 "YELLOW PAGES"
                       10 "MOTOR VEHICLES ADMIN, INTOXICATED DRIVER"
                       11 "PRIVATE REFERRAL" 12 "SCHOOL"
                       13 "INSURANCE COMPANY" 14 "TV AD" 88 "OTHER" ;
label define A10       -9 "INAPPLICABLE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED/NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "NO PAYMENT" 2 "CLIENT SELF PAYMENT"
                       3 "PRIVATE HEALTH INSURANCE, FEE-FOR-SERVIC"
                       4 "PRIVATE HEALTH INSURANCE, HMO/PPO/MANAGE"
                       5 "CRIMINAL JUSTICE SYSTEM" 6 "MEDICAID" 7 "MEDICARE"
                       8 "OTHER PUBLIC FUNDING"
                       9 "EMPLOYEE ASSISTANCE PROGRAM/PLAN"
                       10 "INSURANCE, FEE -FOR-SERVICE OR MANAGED C"
                       11 "MEDICAL COUPON" 12 "RESEARCH GRANT PAYMENT"
                       13 "HAP" 14 "WORKERS COMPENSATION"
                       15 "CONTRACT/SLIDING FEE" 16 "50/50 CLIENT, INSURANCE"
                       17 "SCHOOL PROGRAM" 66 "NOT PERMITTED TO ABSTRACT"
                       88 "OTHER" ;
label define A11       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A14       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "MALE" 2 "FEMALE" ;
label define A15       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "WHITE" 2 "BLACK"
                       3 "AMERICAN INDIAN OR ALASKAN NATIVE"
                       4 "ASIAN OR PACIFIC ISLANDER"
                       5 "OTHER NON-WHITE/MIXED RACE"
                       8 "OTHER, NOT FURTHER CODED" ;
label define A16       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HISPANIC"
                       2 "NOT OF HISPANIC ORIGIN" ;
label define A17       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NEVER MARRIED"
                       1 "MARRIED/COMMON LAW" 2 "WIDOWED"
                       3 "SEPARATED/DIVORCED" 4 "SINGLE"
                       8 "OTHER NOT FURTHER CODED" ;
label define A18       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A19       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A20       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED/NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NO STABLE ARRANGEMENT (INCLUDE HOMELESS,"
                       1 "WITH SPOUSE/PARTNER" 2 "WITH PARENT(S)"
                       3 "WITH OTHER FAMILY" 4 "WITH FRIENDS" 5 "ALONE"
                       6 "WITH NO OTHER ADULT(S)/CHILDREN ONLY"
                       7 "CORRECTIONAL FACILITY" 8 "OTHER INSTITUTION"
                       88 "OTHER, NOT FURTHER CODED" ;
label define A21       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "LESS THAN 8 YEARS" 2 "8 - 11 YEARS"
                       3 "LESS THAN H.S. GRADUATE, NOT OTHERWISE S"
                       4 "H.S. GRADUATE/GED" 5 "SOME COLLEGE"
                       6 "COLLEGE GRADUATE" 7 "POSTGRADUATE"
                       8 "OTHER, NOT FURTHER CODED" ;
label define A22       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A23       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "FULL-TIME (35HRS/WK OR MORE)"
                       2 "PART-TIME (LESS THAN 35 HRS/WK)"
                       3 "EMPLOYED, NOT OTHERWISE SPECIFIED"
                       4 "KEEPING HOUSE, NOT OTHERWISE EMPLOYED" 5 "RETIRED"
                       6 "DISABLED" 7 "INMATE" 8 "UNEMPLOYED" 9 "LAID OFF"
                       10 "STUDENT" 11 "ON PROBATION FROM JOB, SUSPENDED"
                       12 "ON LEAVE, MEDICAL LEAVE, ON WORKERS COMP"
                       13 "IRREGULAR" 14 "NACO" 88 "OTHER, NOT FURTHER CODED" ;
label define A24       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "CLERICAL WORKER" 2 "SALES WORKER"
                       3 "SERVICE WORKER" 4 "PRIVATE HH WORKER"
                       5 "SKILLED WORKER OR CRAFTSMAN" 6 "LABORER"
                       7 "OPERATOR OR MACHINE OPERATOR"
                       8 "TRANSPORTATION EQUIPMENT OPERATOR"
                       9 "FARM LABORER)" 10 "FARMER OR FARM MANAGER"
                       11 "MANAGER/ADMINISTRATOR" 12 "LAY COUNSELOR"
                       13 "PROFESSIONAL/TECHNICAL" 14 "STUDENT"
                       15 "DRUG DEALER, GAMBLER, ETC, OTHER ILLEGAL"
                       86 "EMPLOYER GIVEN/NO OCCUPATION GIVEN"
                       88 "OCCUPATION SPECIFIED, MISCELLANEOUS CODE" ;
label define A25       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A26       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A27       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A28       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A29       -7 "NOT ASCERTAINED" ;
label define A30A      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A30B      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A30C      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A30D      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A30E      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A30F      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A30G      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A30H      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A30I      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A30J      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES"
                       6 "NOT PERMITTED TO ABSTRACT" ;
label define A31       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NONE" 1 "YES" ;
label define A32       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE"
                       1 "YES, ANTIDEPRESSANT" 2 "YES, ANTIPSYCHOTIC"
                       3 "YES, BOTH" ;
label define A33A      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES" ;
label define A33B      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES" ;
label define A33C      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES" ;
label define A33D      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES" ;
label define A33E      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES" ;
label define A33F      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" 1 "YES" ;
label define A34       -7 "NOT ASCERTAINED" -4 "DATA OUT OF RANGE" ;
label define A35       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NONE" ;
label define A36       -9 "NOT APPLICABLE, CLIENT IS MALE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NOT PREGNANT"
                       1 "PREGNANT" ;
label define A37       -9 "NOT APPLICABLE, CLIENT IS MALE, OR CLIEN"
                       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NOT PREGNANT" 1 "PREGNANT"
                       2 "PREGNANT, BABY BORN DURING TREATMENT" ;
label define A38       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "DRUG ABUSE ONLY (EXCLUDING ALCOHOL)"
                       2 "ALCOHOL ABUSE ONLY" 3 "ALCOHOL AND DRUG ABUSE"
                       4 "SUSPECTED SUBSTANCE ABUSE PROBLEM, EVALU"
                       5 "FEAR OF RELAPSE" 6 "TO TREATMENT DIRECT FROM JAIL"
                       8 "OTHER, NOT FURTHER CODED" ;
label define A39CN     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NO DIAGNOSIS SPECIFIED" 1 "ONE DIAGNOSIS SPECIFIED"
                       2 "TWO DIAGNOSES SPECIFIED"
                       3 "THREE DIAGNOSES SPECIFIED"
                       4 "FOUR DIAGNOSES SPECIFIED"
                       5 "FIVE DIAGNOSES SPECIFIED"
                       6 "SIX DIAGNOSES SPECIFIED"
                       7 "SEVEN DIAGNOSES SPECIFIED"
                       8 "EIGHT DIAGNOSES SPECIFIED" ;
label define A39A      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A39B      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A39C      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A39D      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A39E      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A40EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A40LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A40AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A41EU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO/NEVER USED" 1 "YES" ;
label define A41LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A41AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A42EU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO/NEVER USED" 1 "YES" ;
label define A42LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A42AGE    -9 "INAPPLICABLE" -7 "NOT ASCERTAINED"
                       -4 "DATA OUT OF RANGE" ;
label define A43EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A43LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A43AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A44EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A44LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A44AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A45EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A45LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A46EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A46LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A46AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A47EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A47LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A47AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A48EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A48LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A48AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A49EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A49LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A49AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A50EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A50LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A50AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A51EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A51LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A51AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A52EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A52OTH    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "MIDOL/BENEDRYL"
                       2 "EXTRA STRENGTH TYLENOL NIGHT TIME" 3 "TYLENOL"
                       4 "BENEDRYL/CAFFEINE PILLS" 5 "TAGAMENT" 6 "NYQUIL"
                       7 "COUGH MEDICINE, COUGH SYRUP" 8 "ZOLOFT 200"
                       9 "CODINE" 10 "CAFFEINE PILLS, NO DOZ, CAFFEINE"
                       11 "IBUPROFEN AND MIDOL" 12 "MINITHINS" 13 "ASPIRIN"
                       14 "EPIDREINE" 15 "DIET PILLS"
                       16 "TYLENOL WITH CODEINE" 17 "MULTIVITAMIN"
                       18 "PAIN PILLS" 19 "ADVIL, IBUPROFIN, MOTRIN"
                       20 "ELAVIL" 21 "DRAMAMIN" 22 "UNISOM" 23 "AFFEDRIN"
                       24 "ALEVE" 25 "SLEEPING PILLS" 26 "XANAX" 27 "VICODIN"
                       28 "DARVACOT" ;
label define A52LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A52AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A53EU     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO/NEVER USED" 1 "YES" ;
label define A53LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A53AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A54EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A54LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A54AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A55EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A55LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A55AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A56EU     -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO/NEVER USED"
                       1 "YES" ;
label define A56LU     -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A56AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A57       -7 "NOT ASCERTAINED" 0 "NO SUBSTANCE OF CHOICE"
                       40 "CRACK" 41 "COCAINE" 42 "HEROIN"
                       43 "METHADONE-NON-TX" 44 "OTHER OPIATES"
                       45 "BARBITURATES" 46 "BENZODIZEPINES"
                       47 "OTHER SEDATIVES/HYPNOTICS" 48 "AMPHETAMINES"
                       49 "MARIJUANA, HASHISH, THC" 50 "HALLUCINOGENS"
                       51 "INHALANTS" 52 "OVER-THE-COUNTER" 53 "ALCOHOL"
                       54 "TOBACCO" 55 "OTHER DRUG1" 56 "OTHER DRUG2"
                       96 "MULTIPLE DRUGS NAMED" ;
label define A58A      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A58B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A58C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAILY" 2 "REGULARLY BUT NOT DAILY"
                       3 "SPORADICALLY" ;
label define A59       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A60A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A60B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A60C      -9 "INAPPLICABLE" -8 "REFUSED"
                       -7 "YES-NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, TYPE NOT SPECIFIED" 2 "BREATH, BREATHALIZER"
                       3 "DRUG PANEL 5-EMIT" 4 "YES-RPR" ;
label define A61       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ONE TIME ONLY"
                       2 "MORE THAN ONCE, AT REGULAR INTERVALS"
                       3 "MORE THAN ONCE, RANDOMLY (TIME UNKNOWN T"
                       4 "MORE THAN ONCE, BOTH AT REGULAR INTERVAL"
                       5 "MORE THAN ONCE, INTERVALS NOT SPECIFIED"
                       8 "OTHER, NOT FURTHER CODED" ;
label define A62FOP    -9 "NEGATIVE TEST RESULT OR INAPPLICABLE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "POSITIVE RESULTS" ;
label define A62FCO    -9 "NEGATIVE TEST RESULT OR INAPPLICABLE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "POSITIVE RESULTS" ;
label define A62FTHC   -9 "NEGATIVE TEST RESULT OR INAPPLICABLE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "POSITIVE RESULTS" ;
label define A62FOTH   -9 "NEGATIVE TEST RESULT OR INAPPLICABLE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "POSITIVE RESULTS" ;
label define A62LOP    -9 "NEGATIVE TEST RESULT OR INAPPLICABLE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "POSITIVE RESULTS" ;
label define A62LCO    -9 "NEGATIVE TEST RESULT OR INAPPLICABLE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "POSITIVE RESULTS" ;
label define A62LTHC   -9 "NEGATIVE TEST RESULT OR INAPPLICABLE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "POSITIVE RESULTS" ;
label define A62LOTH   -9 "NEGATIVE TEST RESULT OR INAPPLICABLE" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       1 "POSITIVE RESULTS" ;
label define A63       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -4 "OTHER"
                       0 "NO PRIOR TREATMENT EPISODES" ;
label define A64       -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING" ;
label define A65       -9 "INAPPLICABLE, LEAVE TABLE BLANK" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NONE (REPORTED OR LOGICALLY ASSIGNED)"
                       1 "YES, ONE EPISODE REPORTED"
                       2 "YES, TWO EPISODES REPORTED"
                       3 "YES, THREE EPISODES REPORTED"
                       4 "YES, FOUR EPISODES REPORTED"
                       5 "YES, FIVE EPISODES REPORTED"
                       6 "YES, SIX EPISODES, CONTINUATION TABLE US" ;
label define A65AR     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65AF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65AT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65AD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A65BR     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65BF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65BT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65BD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A65CR     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65CF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65CT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65CD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A65DR     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65DF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65DT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65DD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A65ER     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65EF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65ET     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65ED     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A65FR     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65FF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65FT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65FD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A65GR     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65GF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65GT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65GD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A65HR     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65HF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65HT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65HD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A65IR     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65IF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65IT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65ID     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A65JR     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "ALCOHOL ABUSE ONLY"
                       2 "DRUG ABUSE ONLY"
                       3 "COMBINED ALCOHOL AND DRUG ABUSE" ;
label define A65JF     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "HERE" 2 "ELSEWHERE" ;
label define A65JT     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "INPATIENT OR RESIDENTIAL"
                       2 "OUTPATIENT" 3 "DETOX" ;
label define A65JD     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "DID NOT COMPLETE TREATMENT"
                       1 "COMPLETED TREATMENT"
                       2 "TRANSFERRED TO THIS FACILITY" ;
label define A66       -9 "INAPPLICABLE, CLIENT TYPE IS METH DIS OR"
                       -8 "REFUSED" -7 "NOT ASCERTAINED/UNABLE TO DETERMINE"
                       -6 "DON'T KNOW" ;
label define A67A      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67AN     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A67B      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILITY" ;
label define A67BN     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" ;
label define A67C      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67CN     -9 "INAPPLICABLE" -7 "NOT ASCERTAINED" ;
label define A67D      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67DN     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A67E      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67F      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67G      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67H      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67I      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67J      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67K      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67L      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67M      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67N      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67O      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67P      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILTY" ;
label define A67Q      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILITY" ;
label define A67R      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILITY" ;
label define A67S      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILITY" ;
label define A67T      -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, IN THIS FACILITY"
                       2 "YES, SOMETIMES HERE, SOMETIMES ELSEWHERE"
                       3 "YES, NOT IN THIS FACILITY" ;
label define A68       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO"
                       1 "YES, ONE LISTED BELOW" 2 "YES, TWO LISTED BELOW"
                       3 "YES, THREE LISTED BELOW"
                       4 "YES, MORE THAN THREE, SEE COMMENTS" ;
label define A68A1     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "AMBIEN" 2 "ANAPROX" 3 "BROMATAPP"
                       4 "BUSPER" 5 "CLARITIN D" 6 "CLONIDINE" 7 "CYLERT"
                       8 "DESYREL" 9 "DEPAKOTE" 10 "DOXYCYCLINE" 11 "EFFEXOR"
                       12 "EPIVIR" 13 "EYE DROPS" 14 "IBUPROFEN, ADVIL"
                       15 "KLONAPIN" 16 "LOMOTIL" 17 "MOTRIN"
                       18 "NAPROSYN, ALEVE" 19 "NORVASC" 20 "PAXIL"
                       21 "PENICILLIN, PEN VK" 22 "PROZAC" 23 "TRAZODONE"
                       24 "TRIMETHOPRIM" 25 "TUSSI"
                       26 "TYLENOL, ACETAMINOPHEN" 27 "VENTOLIN" 28 "ZERIT"
                       29 "GULAFED CAPS" 30 "KETLEX" 31 "DIPHENHYDRAMINE"
                       32 "AMITRIPTYLINE, ELAVIL" 33 "CARISOPRODOL"
                       34 "CODEINE" 35 "DILATIN" 36 "VALIUM" 37 "TEGRETOL"
                       38 "XANAX" 39 "DEMORAL"
                       40 "VISTAREL, VISTARIL, VISTORIL" 41 "TORADOL"
                       42 "ANTABUSE" 43 "EUCHOR" 44 "IMOPRAMINE"
                       45 "DEPOLATE" 46 "TROZODUC" 47 "DCYOHBO" 48 "PERCIDAN"
                       49 "DARVOCET" 50 "TYLOX" 51 "DESIPRAMINE" 52 "ZANTAC"
                       53 "BENTAL" 54 "LITHIUM" 55 "NAVANE" 56 "COGENTIN"
                       57 "LIBRIUM" 58 "ATIVAN" 59 "HUMULIN" 60 "TYLENOL 325"
                       61 "ZOVIRAX" 62 "CATAPRES PATCH" 63 "K-DUR"
                       64 "TENORNIN" 65 "MOTRIN (600)"
                       66 "THERAHIST COUGH SYRUP" 67 "KEFLEX" 68 "PROCARDIA"
                       69 "SINEQUIN" 70 "ISONIAZID" 71 "DOXEPIN"
                       72 "IMIPANINE" 73 "HYDROXYZINE" 74 "DISULFIRAM"
                       75 "AXID, ACID CONTROL MEDICINE" 76 "ZOLOFT"
                       77 "VICODIN" 78 "LORAZEPAN" 79 "PYRIDOXINE"
                       80 "TRIMAX" 81 "CEFZIL" 82 "GUIATUSS" 83 "PHENYLPROP"
                       84 "ALBUTEROL" 85 "BECONASE" 86 "DURATUSS"
                       87 "FLUORINONILE CREAM" 88 "GLYBURIDE"
                       89 "PSYCHOTROPIC MEDS" 90 "SOMA" 91 "VEETIDS"
                       92 "PLENDIL" 93 "HYDROCHOROTLIAZIDE" 94 "FELODIPINE"
                       95 "PSEUDOEPHEDRINE, SUDAFED" 96 "DIFLUCAN"
                       97 "RIFAMPIN" 98 "RETROVIR" 99 "ATORANQUINE"
                       100 "TOFRANIL" 101 "TRILAFON" 102 "DIZERYPERMIM"
                       103 "PRALASAC" 104 "ALACTONE"
                       105 "VITAMINS, OR A VITAMIN" 106 "ASPIRIN"
                       107 "IRON, FERROS SULFATE" 108 "CHLORDIAZEPOXIDE"
                       109 "MAALOX" 110 "PRENATAL VITAMINS" 111 "AMOXICILLIN"
                       112 "VOLTAREN" 113 "ERYTHROMYCEN" 114 "PROMETHAZINE"
                       115 "METRUNIDZOLE" 116 "ATENOLOL" 117 "ULTRAM"
                       118 "METFORMIN" 119 "INSULIN" 120 "BACTRACIN"
                       121 "FLAGYL" 122 "CIPROFLOXCIN" 123 "PHENEGAN"
                       124 "FERROUS SULFATE (USE 107)" 125 "LABRAMYCIN"
                       126 "TYLENOL WITH CODEINE, TYLENOL #3" 127 "HALDOL"
                       128 "BENEDRYL" 129 "CHLORTRIMETON" 130 "SMZ/TMD"
                       131 "EQUATE" 132 "SERZONE" 133 "NALDOCON" 134 "SURFAK"
                       135 "PROVENTIL INHALER/NEBULIZER" 136 "TORODAL"
                       137 "AMOXIL" 138 "METHYLPRED" 139 "ESKALITH"
                       140 "PHENOBARBITOL" 141 "WELLBUTRIN" 142 "REVIA"
                       143 "ANTIBIOTICS, NOT NAMED" 144 "MICRONASE"
                       145 "LOPRESSOR" 146 "BUSBON"
                       147 "ASTHMA INHALER/MEDICINES"
                       148 "GLYIZIDE (FOR DIABETICS)" 149 "AZT"
                       150 "RISPERDAL" 151 "BEROCCA" 152 "MYLANTA"
                       153 "TETRACYCLINE" 154 "ANTIPYRLBENZOCAINE"
                       155 "E-MYCIN" 156 "TRI-LEVLEN" 157 "TRIMETHOBENZAMIDE"
                       158 "PROPRAPH" 159 "PISCARDIA" 160 "THORAZINE"
                       161 "PREMARIN" 162 "FAMVIR" 163 "DESORIMETASONE"
                       164 "ANUSOL" 165 "SENNA" 166 "HYDROGEN PEROXIDE"
                       167 "BENZOYL PEROXIDE" 168 "TOLNAFLATE"
                       169 "LACHYDRIN OR LACHYDIA" 170 "HYDERZINE"
                       171 "EURAX CREAM" 172 "ATARAX" 173 "CIPRO"
                       174 "MYCFLEX CREAM (MYCELEX CREAM?)" 175 "TAGAMET"
                       176 "PAMELOR" 177 "NORTRIPTYLYN" 178 "OLANZAPINE"
                       179 "NALTRAVONE" 180 "NALTAXORE" 181 "SERTRALINE"
                       182 "HEART MEDICINE" 183 "BLOOD PRESSURE MEDICINE"
                       184 "MELLARIL" 185 "PROLIXIN" 186 "PROLIXIN DECANDATE"
                       187 "RITALIN" 188 "SUMUCIN (FOR ACNE)" 189 "ADDERALL"
                       190 "LITHOBID" 191 "CALAN RS" 192 "TRAYENE"
                       193 "ZOCORE" 194 "ANATOL" 195 "THYROID MEDICINE"
                       196 "ACCUDE" 197 "AMBU" 198 "ALDACTONE" 199 "INDEROL"
                       200 "HYDROCOO/APAP" 201 "DIAZEPAM" 202 "LORCET"
                       203 "TOCOZ" 204 "FULICUN" 205 "INDOCIN"
                       206 "GLUCATROL" 207 "FLEXERIL" 208 "THIAMINE"
                       209 "CARAFATE" 210 "BROMOCRIPTINE" 211 "ELAVIL"
                       212 "FUROSEMIDE" 213 "LUTENSIN" 214 "EMYACIN"
                       215 "PREDNISONE" 216 "SCHIZOPRENIA MEDS" 217 "THEODUR"
                       218 "PROVESTIL" 219 "CYNTROID" 220 "NPD HUMILIN"
                       221 "STODBID" 222 "RETIMO" 223 "VIDEX" 224 "FIORERAL"
                       225 "SYNTHROID" 226 "TB MEDS" 227 "MORPHINE"
                       228 "NICLOXACILLIN" 229 "COLACE" 230 "COMPAZIN"
                       231 "LOTRIMIN" 232 "PRONEUHL" 233 "PROVERTAD"
                       234 "INH" 235 "DAXIL" 236 "CLIMDAMYCIN" 237 "INIVASE"
                       238 "EPIRIE" 239 "SYNOLAR" 240 "AUGMENTIN"
                       241 "DAYPRO" 242 "ESTROGEN" 243 "ROBAXIN"
                       244 "BICILLIN" 245 "ROBITUSSIN" 246 "PITOCIN"
                       247 "FESOG" 248 "PNV" 249 "PROVERA" 250 "TRILPONT"
                       251 "PROPANDOL" 252 "AMPICILLIN" 253 "SLOHID"
                       254 "PEN UK" 255 "VASOTEX" 256 "AEROLBID"
                       257 "CARDIXEM" 258 "LITIBIA" 259 "SEREVENT"
                       260 "REMERON" 261 "BADOFEN" 262 "SUCRALFATE"
                       263 "NAAROSYN" 264 "REBAXIN" 265 "ATROVENT"
                       266 "DIANZAPINE" 267 "CUREX" 268 "FE SO4"
                       269 "NIFEDIPINE" 270 "ALKA SELTZER" 271 "NAPROXEN"
                       272 "SUPHEDRINE" 273 "DARVON" 274 "ZYPREXA"
                       275 "PRINCIPEN" 276 "BIAXIN" 277 "ATRIPALIN"
                       278 "PERCOCERT" 279 "RELATEN" 280 "MILK OF MAGNESIA"
                       281 "ZESTRIOL" 282 "VALPROIC" 283 "REZULIN"
                       284 "CARDIZEN" 285 "AIPRAZOLAM" 286 "DIFLUCON"
                       287 "ACYCLOVIN" 288 "SELSUM LOTION" 289 "CEPHALEXIN"
                       290 "TRIAMICINOLONE" 291 "FLUVOYAMINE"
                       292 "DIVALPROEX" 293 "ENTEX" 294 "BACTRIM D.S"
                       295 "NICARDIPINE" 296 "VERAPAMIL" 297 "NOVOLIN"
                       298 "TRIVIL" 299 "BUTHEONTROL PILLS" 300 "PREVACID"
                       301 "IMURAN" 302 "CEFTIN" 303 "PHENYTOIN"
                       304 "FLUOXETINE" 305 "PECID AC" 306 "HABOPERIDOL"
                       307 "BENZTROPINE" 308 "THIOTHIZENE" 309 "CERENTIL"
                       310 "PRITOXEC" 311 "SULFANETHOXZOLE" 312 "SYMMETREL"
                       313 "ACETAMINOPHEN" 314 "PROPULSID" 315 "CLOZARIL"
                       316 "TRITEC" 317 "ISPERDONE" 318 "VICODRID"
                       319 "KOZOR" 320 "NELFINAVIE" 321 "CLARODENE"
                       322 "TEGIOXAL" 323 "AZITHROMYEIN" 324 "NORTRIPTICINE"
                       325 "FERNOSEMIDE" 326 "ALPRAZOLAM" 327 "ROXICET"
                       328 "LISINOPRIL" 329 "CHLORDIAZOPOXIDE"
                       330 "DENCILLIN" 331 "NASAL SPRAY" 332 "DIMIPRAMINE"
                       333 "FLENEMIL" 334 "HODINE XL" 335 "ACUPRIL"
                       336 "HOZOL" 337 "DUIRETIC" 338 "DIMOXICYLEN"
                       339 "QUEMAPRIL HCL ACCUPRIL" 340 "DALMANE"
                       341 "DELTASONE" 342 "HYDROXYCLORS" 343 "HALCION"
                       344 "HYDRECED" 345 "PRILOSEE" 346 "GLYBURIDEHOZOL"
                       347 "PONDIMIN" 348 "IONAMIN" 349 "BECLOVENT"
                       350 "CILYBURIDE" 351 "NYQUIL" 352 "DYSTHYMIA"
                       353 "ALLOPUINO" 354 "SERAZ" 355 "ATTAVAT"
                       356 "NITROGLYCERIN" 357 "RYTHMEL" 358 "PROCANAMIDE"
                       359 "REGLAN" 360 "CYCLOBENZAPRIN" 361 "CHLORPROMAZINE"
                       362 "KEMADRINE" 363 "FLURBIPROFIN" 364 "DIDIFENAC"
                       365 "IRI-CHROMALSANE" 366 "METOROLOL TARTRATE"
                       367 "DUCOSOTE" 368 "ROXIPRIN" 369 "DICLOXACILLIN"
                       370 "POTASSIUM" 371 "SUDAFED" 372 "IRIAZLSLEM"
                       373 "LOESTRINE" 374 "COUMODIN" 375 "VENTYLIN"
                       376 "DOCUISCITE" 377 "ZYPRIZA" 378 "UNISOM"
                       379 "ALEVE" 380 "MYSOLENE" 381 "PEGRATOL"
                       382 "AMOC/CLORAL/AUGMERTIA" 383 "LASIX" 384 "MONOPRIL"
                       385 "BACTRIA" 386 "AUGMENTIA" 387 "ASA"
                       388 "ALPROZOLAM" 389 "METRO CARBROL" 390 "ORUVAIL"
                       391 "PRILOSRC" 392 "LOXITANE" 393 "ZYPROXIN"
                       394 "BERPLEX PLUS" 395 "KETOPROFEN" 396 "LOPERAMIDE"
                       397 "VERTIDO" 398 "BRONCLODILATOR" 399 "CEFTER"
                       400 "HABITROL PATCH" 401 "CAPTOPRIL"
                       402 "PREPHENAZINE" 403 "NAXIDE" 404 "CLONAZEPAM"
                       405 "ZANAX" 406 "DEREYL" 407 "ZINEGUAN" 408 "DIFLUM"
                       409 "DAPCN" 410 "BACTRUM" 411 "TEGAMET" 412 "LIORASIL"
                       413 "NEFAZODONE" 414 "CONGISTAID" 415 "NALTREXONE"
                       416 "LEVOGUIN" 417 "GLIPIZID" 418 "SELDANE"
                       419 "LUVOX" 420 "ADALACK" 421 "PAXIN"
                       422 "CAPRICE III" 423 "LODENE" 424 "PERCOCET"
                       425 "CILIQUAN" 426 "SONBIEN" 427 "LICOZ" 428 "PEPAD"
                       429 "HYDROCODONE" 430 "VALPORIC ACID" 431 "PVK"
                       432 "FIOSOCAT" 433 "PROPOXY-NAPAP" 434 "DEBROX"
                       435 "MIDRIN" 436 "MICONAZOLE" 437 "ROSPERIDONE"
                       438 "PROPRANOLOL" 439 "HIZONE" 440 "PREMADEN"
                       441 "KLONIDINE" 442 "LEVOTHYROXINE SODIUM"
                       443 "PHENCIZOPYRDINE" 444 "TRUPROFEN" 445 "FOLATE"
                       446 "PAN VA" 447 "DIPHENOXYLATE" 448 "NICOTINE REFREM"
                       449 "TIAC" 450 "HZMACORT" 451 "NAPRALAN"
                       452 "TEMAXIPAN" 453 "RIFADIN" 454 "ZYRTEX"
                       455 "MEVACOR" 456 "VIFLEX" 457 "COMPAZINE" 458 "HCTZ"
                       459 "K-LYTE" 460 "DIABETA" 461 "ACIFED"
                       462 "CLORIDINE" 463 "PYRIMETHAMINE"
                       464 "SLEEPING PILLS" 465 "CAPTAPRIL"
                       466 "TIMOLOLMALEATG" 467 "CIMETIDINE" 468 "TRYSOPT"
                       469 "HYDROCORTISONE" 470 "METHEGRINE" 471 "TERAZOL"
                       472 "CLIOCIN VAGINAL CREAM" 473 "COMBIVER"
                       474 "PHERONOL" 475 "ULTRAVALT CREAM" 476 "LISINOGNIL"
                       477 "OXYCANTIN" 478 "CRIXIVCEN" 479 "TBID"
                       480 "VERCERIL" 481 "DILTEAZEN" 482 "DEXAMETHASON"
                       483 "NICITROL" 484 "DESOROL" 485 "FIORPAP" 486 "D3I"
                       487 "STAVODINE" 488 "PROCARDIN" 489 "STELAZINE"
                       490 "ZALATAN" 491 "VANCENASE" 492 "BUTRIN"
                       493 "ESSEVOR" 494 "MATAIN" 495 "NICODERM PATCH"
                       496 "PERCOCOET" 497 "SANDOGLOBULIN INFUSION"
                       498 "MSAID" 499 "DONNATAL" 500 "TRESIDONE"
                       501 "PREMETHOZINE" 502 "CODAMINE SYRUP"
                       503 "FLAPHENOZINE" 504 "CUMIDIN" 505 "HYTRIN"
                       506 "POLOMAINE" 507 "TINANCIN" 508 "DIOVAN" 509 "IBU"
                       510 "TROPOMINE" 511 "LANOXIN" 512 "AMITRIPTY"
                       513 "ALPRAZALAN" 514 "KERLON" ;
label define A68A2     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "AMBIEN" 2 "ANAPROX" 3 "BROMATAPP"
                       4 "BUSPER" 5 "CLARITIN D" 6 "CLONIDINE" 7 "CYLERT"
                       8 "DESYREL" 9 "DEPAKOTE" 10 "DOXYCYCLINE" 11 "EFFEXOR"
                       12 "EPIVIR" 13 "EYE DROPS" 14 "IBUPROFEN, ADVIL"
                       15 "KLONAPIN" 16 "LOMOTIL" 17 "MOTRIN"
                       18 "NAPROSYN, ALEVE" 19 "NORVASC" 20 "PAXIL"
                       21 "PENICILLIN, PEN VK" 22 "PROZAC" 23 "TRAZODONE"
                       24 "TRIMETHOPRIM" 25 "TUSSI"
                       26 "TYLENOL, ACETAMINOPHEN" 27 "VENTOLIN" 28 "ZERIT"
                       29 "GULAFED CAPS" 30 "KETLEX" 31 "DIPHENHYDRAMINE"
                       32 "AMITRIPTYLINE, ELAVIL" 33 "CARISOPRODOL"
                       34 "CODEINE" 35 "DILATIN" 36 "VALIUM" 37 "TEGRETOL"
                       38 "XANAX" 39 "DEMORAL"
                       40 "VISTAREL, VISTARIL, VISTORIL" 41 "TORADOL"
                       42 "ANTABUSE" 43 "EUCHOR" 44 "IMOPRAMINE"
                       45 "DEPOLATE" 46 "TROZODUC" 47 "DCYOHBO" 48 "PERCIDAN"
                       49 "DARVOCET" 50 "TYLOX" 51 "DESIPRAMINE" 52 "ZANTAC"
                       53 "BENTAL" 54 "LITHIUM" 55 "NAVANE" 56 "COGENTIN"
                       57 "LIBRIUM" 58 "ATIVAN" 59 "HUMULIN" 60 "TYLENOL 325"
                       61 "ZOVIRAX" 62 "CATAPRES PATCH" 63 "K-DUR"
                       64 "TENORNIN" 65 "MOTRIN (600)"
                       66 "THERAHIST COUGH SYRUP" 67 "KEFLEX" 68 "PROCARDIA"
                       69 "SINEQUIN" 70 "ISONIAZID" 71 "DOXEPIN"
                       72 "IMIPANINE" 73 "HYDROXYZINE" 74 "DISULFIRAM"
                       75 "AXID, ACID CONTROL MEDICINE" 76 "ZOLOFT"
                       77 "VICODIN" 78 "LORAZEPAN" 79 "PYRIDOXINE"
                       80 "TRIMAX" 81 "CEFZIL" 82 "GUIATUSS" 83 "PHENYLPROP"
                       84 "ALBUTEROL" 85 "BECONASE" 86 "DURATUSS"
                       87 "FLUORINONILE CREAM" 88 "GLYBURIDE"
                       89 "PSYCHOTROPIC MEDS" 90 "SOMA" 91 "VEETIDS"
                       92 "PLENDIL" 93 "HYDROCHOROTLIAZIDE" 94 "FELODIPINE"
                       95 "PSEUDOEPHEDRINE, SUDAFED" 96 "DIFLUCAN"
                       97 "RIFAMPIN" 98 "RETROVIR" 99 "ATORANQUINE"
                       100 "TOFRANIL" 101 "TRILAFON" 102 "DIZERYPERMIM"
                       103 "PRALASAC" 104 "ALACTONE"
                       105 "VITAMINS, OR A VITAMIN" 106 "ASPIRIN"
                       107 "IRON, FERROS SULFATE" 108 "CHLORDIAZEPOXIDE"
                       109 "MAALOX" 110 "PRENATAL VITAMINS" 111 "AMOXICILLIN"
                       112 "VOLTAREN" 113 "ERYTHROMYCEN" 114 "PROMETHAZINE"
                       115 "METRUNIDZOLE" 116 "ATENOLOL" 117 "ULTRAM"
                       118 "METFORMIN" 119 "INSULIN" 120 "BACTRACIN"
                       121 "FLAGYL" 122 "CIPROFLOXCIN" 123 "PHENEGAN"
                       124 "FERROUS SULFATE (USE 107)" 125 "LABRAMYCIN"
                       126 "TYLENOL WITH CODEINE, TYLENOL #3" 127 "HALDOL"
                       128 "BENEDRYL" 129 "CHLORTRIMETON" 130 "SMZ/TMD"
                       131 "EQUATE" 132 "SERZONE" 133 "NALDOCON" 134 "SURFAK"
                       135 "PROVENTIL INHALER/NEBULIZER" 136 "TORODAL"
                       137 "AMOXIL" 138 "METHYLPRED" 139 "ESKALITH"
                       140 "PHENOBARBITOL" 141 "WELLBUTRIN" 142 "REVIA"
                       143 "ANTIBIOTICS, NOT NAMED" 144 "MICRONASE"
                       145 "LOPRESSOR" 146 "BUSBON"
                       147 "ASTHMA INHALER/MEDICINES"
                       148 "GLYIZIDE (FOR DIABETICS)" 149 "AZT"
                       150 "RISPERDAL" 151 "BEROCCA" 152 "MYLANTA"
                       153 "TETRACYCLINE" 154 "ANTIPYRLBENZOCAINE"
                       155 "E-MYCIN" 156 "TRI-LEVLEN" 157 "TRIMETHOBENZAMIDE"
                       158 "PROPRAPH" 159 "PISCARDIA" 160 "THORAZINE"
                       161 "PREMARIN" 162 "FAMVIR" 163 "DESORIMETASONE"
                       164 "ANUSOL" 165 "SENNA" 166 "HYDROGEN PEROXIDE"
                       167 "BENZOYL PEROXIDE" 168 "TOLNAFLATE"
                       169 "LACHYDRIN OR LACHYDIA" 170 "HYDERZINE"
                       171 "EURAX CREAM" 172 "ATARAX" 173 "CIPRO"
                       174 "MYCFLEX CREAM (MYCELEX CREAM?)" 175 "TAGAMET"
                       176 "PAMELOR" 177 "NORTRIPTYLYN" 178 "OLANZAPINE"
                       179 "NALTRAVONE" 180 "NALTAXORE" 181 "SERTRALINE"
                       182 "HEART MEDICINE" 183 "BLOOD PRESSURE MEDICINE"
                       184 "MELLARIL" 185 "PROLIXIN" 186 "PROLIXIN DECANDATE"
                       187 "RITALIN" 188 "SUMUCIN (FOR ACNE)" 189 "ADDERALL"
                       190 "LITHOBID" 191 "CALAN RS" 192 "TRAYENE"
                       193 "ZOCORE" 194 "ANATOL" 195 "THYROID MEDICINE"
                       196 "ACCUDE" 197 "AMBU" 198 "ALDACTONE" 199 "INDEROL"
                       200 "HYDROCOO/APAP" 201 "DIAZEPAM" 202 "LORCET"
                       203 "TOCOZ" 204 "FULICUN" 205 "INDOCIN"
                       206 "GLUCATROL" 207 "FLEXERIL" 208 "THIAMINE"
                       209 "CARAFATE" 210 "BROMOCRIPTINE" 211 "ELAVIL"
                       212 "FUROSEMIDE" 213 "LUTENSIN" 214 "EMYACIN"
                       215 "PREDNISONE" 216 "SCHIZOPRENIA MEDS" 217 "THEODUR"
                       218 "PROVESTIL" 219 "CYNTROID" 220 "NPD HUMILIN"
                       221 "STODBID" 222 "RETIMO" 223 "VIDEX" 224 "FIORERAL"
                       225 "SYNTHROID" 226 "TB MEDS" 227 "MORPHINE"
                       228 "NICLOXACILLIN" 229 "COLACE" 230 "COMPAZIN"
                       231 "LOTRIMIN" 232 "PRONEUHL" 233 "PROVERTAD"
                       234 "INH" 235 "DAXIL" 236 "CLIMDAMYCIN" 237 "INIVASE"
                       238 "EPIRIE" 239 "SYNOLAR" 240 "AUGMENTIN"
                       241 "DAYPRO" 242 "ESTROGEN" 243 "ROBAXIN"
                       244 "BICILLIN" 245 "ROBITUSSIN" 246 "PITOCIN"
                       247 "FESOG" 248 "PNV" 249 "PROVERA" 250 "TRILPONT"
                       251 "PROPANDOL" 252 "AMPICILLIN" 253 "SLOHID"
                       254 "PEN UK" 255 "VASOTEX" 256 "AEROLBID"
                       257 "CARDIXEM" 258 "LITIBIA" 259 "SEREVENT"
                       260 "REMERON" 261 "BADOFEN" 262 "SUCRALFATE"
                       263 "NAAROSYN" 264 "REBAXIN" 265 "ATROVENT"
                       266 "DIANZAPINE" 267 "CUREX" 268 "FE SO4"
                       269 "NIFEDIPINE" 270 "ALKA SELTZER" 271 "NAPROXEN"
                       272 "SUPHEDRINE" 273 "DARVON" 274 "ZYPREXA"
                       275 "PRINCIPEN" 276 "BIAXIN" 277 "ATRIPALIN"
                       278 "PERCOCERT" 279 "RELATEN" 280 "MILK OF MAGNESIA"
                       281 "ZESTRIOL" 282 "VALPROIC" 283 "REZULIN"
                       284 "CARDIZEN" 285 "AIPRAZOLAM" 286 "DIFLUCON"
                       287 "ACYCLOVIN" 288 "SELSUM LOTION" 289 "CEPHALEXIN"
                       290 "TRIAMICINOLONE" 291 "FLUVOYAMINE"
                       292 "DIVALPROEX" 293 "ENTEX" 294 "BACTRIM D.S"
                       295 "NICARDIPINE" 296 "VERAPAMIL" 297 "NOVOLIN"
                       298 "TRIVIL" 299 "BUTHEONTROL PILLS" 300 "PREVACID"
                       301 "IMURAN" 302 "CEFTIN" 303 "PHENYTOIN"
                       304 "FLUOXETINE" 305 "PECID AC" 306 "HABOPERIDOL"
                       307 "BENZTROPINE" 308 "THIOTHIZENE" 309 "CERENTIL"
                       310 "PRITOXEC" 311 "SULFANETHOXZOLE" 312 "SYMMETREL"
                       313 "ACETAMINOPHEN" 314 "PROPULSID" 315 "CLOZARIL"
                       316 "TRITEC" 317 "ISPERDONE" 318 "VICODRID"
                       319 "KOZOR" 320 "NELFINAVIE" 321 "CLARODENE"
                       322 "TEGIOXAL" 323 "AZITHROMYEIN" 324 "NORTRIPTICINE"
                       325 "FERNOSEMIDE" 326 "ALPRAZOLAM" 327 "ROXICET"
                       328 "LISINOPRIL" 329 "CHLORDIAZOPOXIDE"
                       330 "DENCILLIN" 331 "NASAL SPRAY" 332 "DIMIPRAMINE"
                       333 "FLENEMIL" 334 "HODINE XL" 335 "ACUPRIL"
                       336 "HOZOL" 337 "DUIRETIC" 338 "DIMOXICYLEN"
                       339 "QUEMAPRIL HCL ACCUPRIL" 340 "DALMANE"
                       341 "DELTASONE" 342 "HYDROXYCLORS" 343 "HALCION"
                       344 "HYDRECED" 345 "PRILOSEE" 346 "GLYBURIDEHOZOL"
                       347 "PONDIMIN" 348 "IONAMIN" 349 "BECLOVENT"
                       350 "CILYBURIDE" 351 "NYQUIL" 352 "DYSTHYMIA"
                       353 "ALLOPUINO" 354 "SERAZ" 355 "ATTAVAT"
                       356 "NITROGLYCERIN" 357 "RYTHMEL" 358 "PROCANAMIDE"
                       359 "REGLAN" 360 "CYCLOBENZAPRIN" 361 "CHLORPROMAZINE"
                       362 "KEMADRINE" 363 "FLURBIPROFIN" 364 "DIDIFENAC"
                       365 "IRI-CHROMALSANE" 366 "METOROLOL TARTRATE"
                       367 "DUCOSOTE" 368 "ROXIPRIN" 369 "DICLOXACILLIN"
                       370 "POTASSIUM" 371 "SUDAFED" 372 "IRIAZLSLEM"
                       373 "LOESTRINE" 374 "COUMODIN" 375 "VENTYLIN"
                       376 "DOCUISCITE" 377 "ZYPRIZA" 378 "UNISOM"
                       379 "ALEVE" 380 "MYSOLENE" 381 "PEGRATOL"
                       382 "AMOC/CLORAL/AUGMERTIA" 383 "LASIX" 384 "MONOPRIL"
                       385 "BACTRIA" 386 "AUGMENTIA" 387 "ASA"
                       388 "ALPROZOLAM" 389 "METRO CARBROL" 390 "ORUVAIL"
                       391 "PRILOSRC" 392 "LOXITANE" 393 "ZYPROXIN"
                       394 "BERPLEX PLUS" 395 "KETOPROFEN" 396 "LOPERAMIDE"
                       397 "VERTIDO" 398 "BRONCLODILATOR" 399 "CEFTER"
                       400 "HABITROL PATCH" 401 "CAPTOPRIL"
                       402 "PREPHENAZINE" 403 "NAXIDE" 404 "CLONAZEPAM"
                       405 "ZANAX" 406 "DEREYL" 407 "ZINEGUAN" 408 "DIFLUM"
                       409 "DAPCN" 410 "BACTRUM" 411 "TEGAMET" 412 "LIORASIL"
                       413 "NEFAZODONE" 414 "CONGISTAID" 415 "NALTREXONE"
                       416 "LEVOGUIN" 417 "GLIPIZID" 418 "SELDANE"
                       419 "LUVOX" 420 "ADALACK" 421 "PAXIN"
                       422 "CAPRICE III" 423 "LODENE" 424 "PERCOCET"
                       425 "CILIQUAN" 426 "SONBIEN" 427 "LICOZ" 428 "PEPAD"
                       429 "HYDROCODONE" 430 "VALPORIC ACID" 431 "PVK"
                       432 "FIOSOCAT" 433 "PROPOXY-NAPAP" 434 "DEBROX"
                       435 "MIDRIN" 436 "MICONAZOLE" 437 "ROSPERIDONE"
                       438 "PROPRANOLOL" 439 "HIZONE" 440 "PREMADEN"
                       441 "KLONIDINE" 442 "LEVOTHYROXINE SODIUM"
                       443 "PHENCIZOPYRDINE" 444 "TRUPROFEN" 445 "FOLATE"
                       446 "PAN VA" 447 "DIPHENOXYLATE" 448 "NICOTINE REFREM"
                       449 "TIAC" 450 "HZMACORT" 451 "NAPRALAN"
                       452 "TEMAXIPAN" 453 "RIFADIN" 454 "ZYRTEX"
                       455 "MEVACOR" 456 "VIFLEX" 457 "COMPAZINE" 458 "HCTZ"
                       459 "K-LYTE" 460 "DIABETA" 461 "ACIFED"
                       462 "CLORIDINE" 463 "PYRIMETHAMINE"
                       464 "SLEEPING PILLS" 465 "CAPTAPRIL"
                       466 "TIMOLOLMALEATG" 467 "CIMETIDINE" 468 "TRYSOPT"
                       469 "HYDROCORTISONE" 470 "METHEGRINE" 471 "TERAZOL"
                       472 "CLIOCIN VAGINAL CREAM" 473 "COMBIVER"
                       474 "PHERONOL" 475 "ULTRAVALT CREAM" 476 "LISINOGNIL"
                       477 "OXYCANTIN" 478 "CRIXIVCEN" 479 "TBID"
                       480 "VERCERIL" 481 "DILTEAZEN" 482 "DEXAMETHASON"
                       483 "NICITROL" 484 "DESOROL" 485 "FIORPAP" 486 "D3I"
                       487 "STAVODINE" 488 "PROCARDIN" 489 "STELAZINE"
                       490 "ZALATAN" 491 "VANCENASE" 492 "BUTRIN"
                       493 "ESSEVOR" 494 "MATAIN" 495 "NICODERM PATCH"
                       496 "PERCOCOET" 497 "SANDOGLOBULIN INFUSION"
                       498 "MSAID" 499 "DONNATAL" 500 "TRESIDONE"
                       501 "PREMETHOZINE" 502 "CODAMINE SYRUP"
                       503 "FLAPHENOZINE" 504 "CUMIDIN" 505 "HYTRIN"
                       506 "POLOMAINE" 507 "TINANCIN" 508 "DIOVAN" 509 "IBU"
                       510 "TROPOMINE" 511 "LANOXIN" 512 "AMITRIPTY"
                       513 "ALPRAZALAN" 514 "KERLON" ;
label define A68A3     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "AMBIEN" 2 "ANAPROX" 3 "BROMATAPP"
                       4 "BUSPER" 5 "CLARITIN D" 6 "CLONIDINE" 7 "CYLERT"
                       8 "DESYREL" 9 "DEPAKOTE" 10 "DOXYCYCLINE" 11 "EFFEXOR"
                       12 "EPIVIR" 13 "EYE DROPS" 14 "IBUPROFEN, ADVIL"
                       15 "KLONAPIN" 16 "LOMOTIL" 17 "MOTRIN"
                       18 "NAPROSYN, ALEVE" 19 "NORVASC" 20 "PAXIL"
                       21 "PENICILLIN, PEN VK" 22 "PROZAC" 23 "TRAZODONE"
                       24 "TRIMETHOPRIM" 25 "TUSSI"
                       26 "TYLENOL, ACETAMINOPHEN" 27 "VENTOLIN" 28 "ZERIT"
                       29 "GULAFED CAPS" 30 "KETLEX" 31 "DIPHENHYDRAMINE"
                       32 "AMITRIPTYLINE, ELAVIL" 33 "CARISOPRODOL"
                       34 "CODEINE" 35 "DILATIN" 36 "VALIUM" 37 "TEGRETOL"
                       38 "XANAX" 39 "DEMORAL"
                       40 "VISTAREL, VISTARIL, VISTORIL" 41 "TORADOL"
                       42 "ANTABUSE" 43 "EUCHOR" 44 "IMOPRAMINE"
                       45 "DEPOLATE" 46 "TROZODUC" 47 "DCYOHBO" 48 "PERCIDAN"
                       49 "DARVOCET" 50 "TYLOX" 51 "DESIPRAMINE" 52 "ZANTAC"
                       53 "BENTAL" 54 "LITHIUM" 55 "NAVANE" 56 "COGENTIN"
                       57 "LIBRIUM" 58 "ATIVAN" 59 "HUMULIN" 60 "TYLENOL 325"
                       61 "ZOVIRAX" 62 "CATAPRES PATCH" 63 "K-DUR"
                       64 "TENORNIN" 65 "MOTRIN (600)"
                       66 "THERAHIST COUGH SYRUP" 67 "KEFLEX" 68 "PROCARDIA"
                       69 "SINEQUIN" 70 "ISONIAZID" 71 "DOXEPIN"
                       72 "IMIPANINE" 73 "HYDROXYZINE" 74 "DISULFIRAM"
                       75 "AXID, ACID CONTROL MEDICINE" 76 "ZOLOFT"
                       77 "VICODIN" 78 "LORAZEPAN" 79 "PYRIDOXINE"
                       80 "TRIMAX" 81 "CEFZIL" 82 "GUIATUSS" 83 "PHENYLPROP"
                       84 "ALBUTEROL" 85 "BECONASE" 86 "DURATUSS"
                       87 "FLUORINONILE CREAM" 88 "GLYBURIDE"
                       89 "PSYCHOTROPIC MEDS" 90 "SOMA" 91 "VEETIDS"
                       92 "PLENDIL" 93 "HYDROCHOROTLIAZIDE" 94 "FELODIPINE"
                       95 "PSEUDOEPHEDRINE, SUDAFED" 96 "DIFLUCAN"
                       97 "RIFAMPIN" 98 "RETROVIR" 99 "ATORANQUINE"
                       100 "TOFRANIL" 101 "TRILAFON" 102 "DIZERYPERMIM"
                       103 "PRALASAC" 104 "ALACTONE"
                       105 "VITAMINS, OR A VITAMIN" 106 "ASPIRIN"
                       107 "IRON, FERROS SULFATE" 108 "CHLORDIAZEPOXIDE"
                       109 "MAALOX" 110 "PRENATAL VITAMINS" 111 "AMOXICILLIN"
                       112 "VOLTAREN" 113 "ERYTHROMYCEN" 114 "PROMETHAZINE"
                       115 "METRUNIDZOLE" 116 "ATENOLOL" 117 "ULTRAM"
                       118 "METFORMIN" 119 "INSULIN" 120 "BACTRACIN"
                       121 "FLAGYL" 122 "CIPROFLOXCIN" 123 "PHENEGAN"
                       124 "FERROUS SULFATE (USE 107)" 125 "LABRAMYCIN"
                       126 "TYLENOL WITH CODEINE, TYLENOL #3" 127 "HALDOL"
                       128 "BENEDRYL" 129 "CHLORTRIMETON" 130 "SMZ/TMD"
                       131 "EQUATE" 132 "SERZONE" 133 "NALDOCON" 134 "SURFAK"
                       135 "PROVENTIL INHALER/NEBULIZER" 136 "TORODAL"
                       137 "AMOXIL" 138 "METHYLPRED" 139 "ESKALITH"
                       140 "PHENOBARBITOL" 141 "WELLBUTRIN" 142 "REVIA"
                       143 "ANTIBIOTICS, NOT NAMED" 144 "MICRONASE"
                       145 "LOPRESSOR" 146 "BUSBON"
                       147 "ASTHMA INHALER/MEDICINES"
                       148 "GLYIZIDE (FOR DIABETICS)" 149 "AZT"
                       150 "RISPERDAL" 151 "BEROCCA" 152 "MYLANTA"
                       153 "TETRACYCLINE" 154 "ANTIPYRLBENZOCAINE"
                       155 "E-MYCIN" 156 "TRI-LEVLEN" 157 "TRIMETHOBENZAMIDE"
                       158 "PROPRAPH" 159 "PISCARDIA" 160 "THORAZINE"
                       161 "PREMARIN" 162 "FAMVIR" 163 "DESORIMETASONE"
                       164 "ANUSOL" 165 "SENNA" 166 "HYDROGEN PEROXIDE"
                       167 "BENZOYL PEROXIDE" 168 "TOLNAFLATE"
                       169 "LACHYDRIN OR LACHYDIA" 170 "HYDERZINE"
                       171 "EURAX CREAM" 172 "ATARAX" 173 "CIPRO"
                       174 "MYCFLEX CREAM (MYCELEX CREAM?)" 175 "TAGAMET"
                       176 "PAMELOR" 177 "NORTRIPTYLYN" 178 "OLANZAPINE"
                       179 "NALTRAVONE" 180 "NALTAXORE" 181 "SERTRALINE"
                       182 "HEART MEDICINE" 183 "BLOOD PRESSURE MEDICINE"
                       184 "MELLARIL" 185 "PROLIXIN" 186 "PROLIXIN DECANDATE"
                       187 "RITALIN" 188 "SUMUCIN (FOR ACNE)" 189 "ADDERALL"
                       190 "LITHOBID" 191 "CALAN RS" 192 "TRAYENE"
                       193 "ZOCORE" 194 "ANATOL" 195 "THYROID MEDICINE"
                       196 "ACCUDE" 197 "AMBU" 198 "ALDACTONE" 199 "INDEROL"
                       200 "HYDROCOO/APAP" 201 "DIAZEPAM" 202 "LORCET"
                       203 "TOCOZ" 204 "FULICUN" 205 "INDOCIN"
                       206 "GLUCATROL" 207 "FLEXERIL" 208 "THIAMINE"
                       209 "CARAFATE" 210 "BROMOCRIPTINE" 211 "ELAVIL"
                       212 "FUROSEMIDE" 213 "LUTENSIN" 214 "EMYACIN"
                       215 "PREDNISONE" 216 "SCHIZOPRENIA MEDS" 217 "THEODUR"
                       218 "PROVESTIL" 219 "CYNTROID" 220 "NPD HUMILIN"
                       221 "STODBID" 222 "RETIMO" 223 "VIDEX" 224 "FIORERAL"
                       225 "SYNTHROID" 226 "TB MEDS" 227 "MORPHINE"
                       228 "NICLOXACILLIN" 229 "COLACE" 230 "COMPAZIN"
                       231 "LOTRIMIN" 232 "PRONEUHL" 233 "PROVERTAD"
                       234 "INH" 235 "DAXIL" 236 "CLIMDAMYCIN" 237 "INIVASE"
                       238 "EPIRIE" 239 "SYNOLAR" 240 "AUGMENTIN"
                       241 "DAYPRO" 242 "ESTROGEN" 243 "ROBAXIN"
                       244 "BICILLIN" 245 "ROBITUSSIN" 246 "PITOCIN"
                       247 "FESOG" 248 "PNV" 249 "PROVERA" 250 "TRILPONT"
                       251 "PROPANDOL" 252 "AMPICILLIN" 253 "SLOHID"
                       254 "PEN UK" 255 "VASOTEX" 256 "AEROLBID"
                       257 "CARDIXEM" 258 "LITIBIA" 259 "SEREVENT"
                       260 "REMERON" 261 "BADOFEN" 262 "SUCRALFATE"
                       263 "NAAROSYN" 264 "REBAXIN" 265 "ATROVENT"
                       266 "DIANZAPINE" 267 "CUREX" 268 "FE SO4"
                       269 "NIFEDIPINE" 270 "ALKA SELTZER" 271 "NAPROXEN"
                       272 "SUPHEDRINE" 273 "DARVON" 274 "ZYPREXA"
                       275 "PRINCIPEN" 276 "BIAXIN" 277 "ATRIPALIN"
                       278 "PERCOCERT" 279 "RELATEN" 280 "MILK OF MAGNESIA"
                       281 "ZESTRIOL" 282 "VALPROIC" 283 "REZULIN"
                       284 "CARDIZEN" 285 "AIPRAZOLAM" 286 "DIFLUCON"
                       287 "ACYCLOVIN" 288 "SELSUM LOTION" 289 "CEPHALEXIN"
                       290 "TRIAMICINOLONE" 291 "FLUVOYAMINE"
                       292 "DIVALPROEX" 293 "ENTEX" 294 "BACTRIM D.S"
                       295 "NICARDIPINE" 296 "VERAPAMIL" 297 "NOVOLIN"
                       298 "TRIVIL" 299 "BUTHEONTROL PILLS" 300 "PREVACID"
                       301 "IMURAN" 302 "CEFTIN" 303 "PHENYTOIN"
                       304 "FLUOXETINE" 305 "PECID AC" 306 "HABOPERIDOL"
                       307 "BENZTROPINE" 308 "THIOTHIZENE" 309 "CERENTIL"
                       310 "PRITOXEC" 311 "SULFANETHOXZOLE" 312 "SYMMETREL"
                       313 "ACETAMINOPHEN" 314 "PROPULSID" 315 "CLOZARIL"
                       316 "TRITEC" 317 "ISPERDONE" 318 "VICODRID"
                       319 "KOZOR" 320 "NELFINAVIE" 321 "CLARODENE"
                       322 "TEGIOXAL" 323 "AZITHROMYEIN" 324 "NORTRIPTICINE"
                       325 "FERNOSEMIDE" 326 "ALPRAZOLAM" 327 "ROXICET"
                       328 "LISINOPRIL" 329 "CHLORDIAZOPOXIDE"
                       330 "DENCILLIN" 331 "NASAL SPRAY" 332 "DIMIPRAMINE"
                       333 "FLENEMIL" 334 "HODINE XL" 335 "ACUPRIL"
                       336 "HOZOL" 337 "DUIRETIC" 338 "DIMOXICYLEN"
                       339 "QUEMAPRIL HCL ACCUPRIL" 340 "DALMANE"
                       341 "DELTASONE" 342 "HYDROXYCLORS" 343 "HALCION"
                       344 "HYDRECED" 345 "PRILOSEE" 346 "GLYBURIDEHOZOL"
                       347 "PONDIMIN" 348 "IONAMIN" 349 "BECLOVENT"
                       350 "CILYBURIDE" 351 "NYQUIL" 352 "DYSTHYMIA"
                       353 "ALLOPUINO" 354 "SERAZ" 355 "ATTAVAT"
                       356 "NITROGLYCERIN" 357 "RYTHMEL" 358 "PROCANAMIDE"
                       359 "REGLAN" 360 "CYCLOBENZAPRIN" 361 "CHLORPROMAZINE"
                       362 "KEMADRINE" 363 "FLURBIPROFIN" 364 "DIDIFENAC"
                       365 "IRI-CHROMALSANE" 366 "METOROLOL TARTRATE"
                       367 "DUCOSOTE" 368 "ROXIPRIN" 369 "DICLOXACILLIN"
                       370 "POTASSIUM" 371 "SUDAFED" 372 "IRIAZLSLEM"
                       373 "LOESTRINE" 374 "COUMODIN" 375 "VENTYLIN"
                       376 "DOCUISCITE" 377 "ZYPRIZA" 378 "UNISOM"
                       379 "ALEVE" 380 "MYSOLENE" 381 "PEGRATOL"
                       382 "AMOC/CLORAL/AUGMERTIA" 383 "LASIX" 384 "MONOPRIL"
                       385 "BACTRIA" 386 "AUGMENTIA" 387 "ASA"
                       388 "ALPROZOLAM" 389 "METRO CARBROL" 390 "ORUVAIL"
                       391 "PRILOSRC" 392 "LOXITANE" 393 "ZYPROXIN"
                       394 "BERPLEX PLUS" 395 "KETOPROFEN" 396 "LOPERAMIDE"
                       397 "VERTIDO" 398 "BRONCLODILATOR" 399 "CEFTER"
                       400 "HABITROL PATCH" 401 "CAPTOPRIL"
                       402 "PREPHENAZINE" 403 "NAXIDE" 404 "CLONAZEPAM"
                       405 "ZANAX" 406 "DEREYL" 407 "ZINEGUAN" 408 "DIFLUM"
                       409 "DAPCN" 410 "BACTRUM" 411 "TEGAMET" 412 "LIORASIL"
                       413 "NEFAZODONE" 414 "CONGISTAID" 415 "NALTREXONE"
                       416 "LEVOGUIN" 417 "GLIPIZID" 418 "SELDANE"
                       419 "LUVOX" 420 "ADALACK" 421 "PAXIN"
                       422 "CAPRICE III" 423 "LODENE" 424 "PERCOCET"
                       425 "CILIQUAN" 426 "SONBIEN" 427 "LICOZ" 428 "PEPAD"
                       429 "HYDROCODONE" 430 "VALPORIC ACID" 431 "PVK"
                       432 "FIOSOCAT" 433 "PROPOXY-NAPAP" 434 "DEBROX"
                       435 "MIDRIN" 436 "MICONAZOLE" 437 "ROSPERIDONE"
                       438 "PROPRANOLOL" 439 "HIZONE" 440 "PREMADEN"
                       441 "KLONIDINE" 442 "LEVOTHYROXINE SODIUM"
                       443 "PHENCIZOPYRDINE" 444 "TRUPROFEN" 445 "FOLATE"
                       446 "PAN VA" 447 "DIPHENOXYLATE" 448 "NICOTINE REFREM"
                       449 "TIAC" 450 "HZMACORT" 451 "NAPRALAN"
                       452 "TEMAXIPAN" 453 "RIFADIN" 454 "ZYRTEX"
                       455 "MEVACOR" 456 "VIFLEX" 457 "COMPAZINE" 458 "HCTZ"
                       459 "K-LYTE" 460 "DIABETA" 461 "ACIFED"
                       462 "CLORIDINE" 463 "PYRIMETHAMINE"
                       464 "SLEEPING PILLS" 465 "CAPTAPRIL"
                       466 "TIMOLOLMALEATG" 467 "CIMETIDINE" 468 "TRYSOPT"
                       469 "HYDROCORTISONE" 470 "METHEGRINE" 471 "TERAZOL"
                       472 "CLIOCIN VAGINAL CREAM" 473 "COMBIVER"
                       474 "PHERONOL" 475 "ULTRAVALT CREAM" 476 "LISINOGNIL"
                       477 "OXYCANTIN" 478 "CRIXIVCEN" 479 "TBID"
                       480 "VERCERIL" 481 "DILTEAZEN" 482 "DEXAMETHASON"
                       483 "NICITROL" 484 "DESOROL" 485 "FIORPAP" 486 "D3I"
                       487 "STAVODINE" 488 "PROCARDIN" 489 "STELAZINE"
                       490 "ZALATAN" 491 "VANCENASE" 492 "BUTRIN"
                       493 "ESSEVOR" 494 "MATAIN" 495 "NICODERM PATCH"
                       496 "PERCOCOET" 497 "SANDOGLOBULIN INFUSION"
                       498 "MSAID" 499 "DONNATAL" 500 "TRESIDONE"
                       501 "PREMETHOZINE" 502 "CODAMINE SYRUP"
                       503 "FLAPHENOZINE" 504 "CUMIDIN" 505 "HYTRIN"
                       506 "POLOMAINE" 507 "TINANCIN" 508 "DIOVAN" 509 "IBU"
                       510 "TROPOMINE" 511 "LANOXIN" 512 "AMITRIPTY"
                       513 "ALPRAZALAN" 514 "KERLON" ;
label define A69       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A69BTD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A69CTD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A69DTD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A70       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A73       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "CLIENT DECEASED"
                       1 "COMPLETED PLANNED TREATMENT"
                       2 "DIDN'T COMPLETE TX, REFERRED/TRANSFERRED"
                       3 "DIDN'T COMPLETE TX, INSURANCE BENEFITS E"
                       4 "DIDN'T COMPLETE TX, NO PAYMENT SOURCE"
                       5 "DIDN'T COMPLETE TX BY ADMINISTRATION CHO"
                       6 "DIDN'T COMPLETE TX BY CLIENT CHOICE"
                       7 "DIDN'T COMPLETE TX, INCARCERATED"
                       8 "DIDN'T COMPLETE TX, NOT OTHERWISE SPECIF"
                       9 "PENDING COMPLETION OF ASSIGNMENT"
                       10 "MUTUAL AGREEMENT TO TERMINATE"
                       11 "LAWYER TERMINATED THERAPY, COURT TERMINA"
                       12 "TREATMENT NEVER STARTED"
                       13 "PROBLEMS WITH TRANSPORTATION" 14 "EVALUATION ONLY"
                       15 "ARRESTED" 16 "MOVED AWAY"
                       17 "DROP OUT, PHYSICAL ILLNESS (E.G.,CANCER)"
                       18 "REFERRED TO NON-SA TREATMENT"
                       19 "MEDICALLY DISCHARGE AFTERCARE" 20 "HAVING A BABY" ;
label define A74CN     -9 "INAP CLIENT TYPE IS METH/IN-TX METH CLIE"
                       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NO DIAGNOSIS SPECIFIED" 1 "ONE DIAGNOSIS SPECIFIED"
                       2 "TWO DIAGNOSES SPECIFIED"
                       3 "THREE DIAGNOSES SPECIFIED"
                       4 "FOUR DIAGNOSES SPECIFIED"
                       5 "FIVE DIAGNOSES SPECIFIED"
                       6 "SIX DIAGNOSES SPECIFIED"
                       7 "SEVEN DIAGNOSES SPECIFIED"
                       8 "EIGHT DIAGNOSES SPECIFIED" ;
label define A74A      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A74B      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A74C      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A74D      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A74E      -9 "NOT APPLICABLE" -7 "NOT ASCERTAINED" -5 "MISSING"
                       0 "NO DIAGNOSIS" 1 "ALCOHOL-INDUCED DISORDER"
                       2 "SUBSTANCE-INDUCED DISORDER"
                       3 "ALCOHOL INTOXICATION" 4 "ALCOHOL DEPENDENCE"
                       5 "OPIOID DEPENDENCE" 6 "COCAINE DEPENDENCE"
                       7 "CANNABIS DEPENDENCE" 8 "OTHER SUBSTANCE DEPENDENCE"
                       9 "ALCOHOL ABUSE" 10 "CANNABIS ABUSE"
                       11 "OTH SUBST ABUSE" 12 "OPIOID ABUSE"
                       13 "COCAINE ABUSE" 14 "ANXIETY DISORDERS"
                       15 "DEPRESSIVE DISORDERS"
                       16 "SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS"
                       17 "BIPOLAR DISORDERS"
                       18 "ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD"
                       19 "OTHER MENTAL HEALTH CONDITION"
                       20 "OTHER CONDITION" ;
label define A75       -9 "INAP CLIENT TYPE IS METH DIS OR IN-TX ME"
                       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NO" 1 "YES, SPECIFY MENTAL ILLNESS BELOW"
                       2 "YES, BUT ILLNESS NOT SPECIFIED" ;
label define A75A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "BI-POLAR AND DEPRESSION"
                       2 "DEPRESSION AND ANXIETY"
                       3 "MAJOR DEPRESSIVE DISORDER RECURRENT/MAJO"
                       4 "DEPRESSION, POSSIBLE DEPRESSION"
                       5 "PANIC DISORDER WITH AGRAPHOBIA"
                       6 "DEPRESSION/SUICIDAL" 7 "BI-POLAR I, II, OR PLAIN"
                       8 "CUNABAIS DEPENDENCE STABALIZE MOOD"
                       9 "IMPULSIVE BEHAVIOR"
                       10 "ANIT-SOCIAL PERSONALITY DISORDER"
                       11 "BI-POLAR/MANIC"
                       12 "BI-POLAR/BORDERLINE PERSONALITY DISORD"
                       13 "AVOIDANT PERSONALITY DISORDER"
                       14 "MAJOR DEPRESSION/DEPENDENT PERSONALITY D"
                       15 "ADJUSTMENT DISORDER/PERSONALITY DISORDER"
                       16 "ANXIETY DISORDER" 17 "ADJUSTMENT DISORDER"
                       18 "SCHIZOAFFECTIVE, SHIZOPHRENIA" 19 "PARANOIA"
                       20 "MULTIPLE PERSONALITY DISORDER OR POSSIBL"
                       21 "SCHIZOPHRENIA AND BI-POLAR"
                       22 "ADJUSTMENT DISORDER/DEPRESSION"
                       23 "DOMESTIC ABUSE" 24 "SEXUAL ADDICTION"
                       25 "PSYCHOTIC DISORDER" 26 "PSYCHIATRIC COMPLICATIONS"
                       27 "PSYCHO-SOCIAL PROBLEMS"
                       28 "DEPRESSION AND PANIC DISORDER"
                       29 "POST TRAUMATIC STRESS DISORDER"
                       30 "DYSTHYMIA DISORDER" 31 "COGNITIVE DEFICITS"
                       32 "DUAL DIAGNOSIS"
                       33 "PASSIVE AGGRESSIVE PERSONALITY DISORDER"
                       34 "HALLUCINATIONS" 35 "SUICIDAL" 36 "ANGER"
                       88 "MANY PROBLEMS LISTED" ;
label define A76       -9 "INAPP CLIENT TYPE IS METH OR IN-TX METH"
                       -8 "REFUSED" -7 "UNABLE TO DETERMINE" -6 "DON'T KNOW"
                       0 "NO" 1 "YES" ;
label define A77       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "SERVICES SPECIFIED" ;
label define A77A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A77B      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A77C      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A77D      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A77E      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A77F      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A77G      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A78       -9 "INAP CLIENT TYPE IS METH/IN-TX METH CLIE"
                       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW"
                       0 "NO TREATMENT" 1 "HOSPITAL INPATIENT"
                       2 "RESIDENTIAL" 3 "OUTPATIENT METHADONE"
                       4 "OUTPATIENT NON-METHADONE"
                       5 "SUBSTANCE ABUSE TREATMENT, NOT OTHERWISE"
                       8 "OTHER, SPECIFY" ;
label define A79       -9 "INAP CLIENT TYPE IS METH OR IN-TX METH C"
                       -8 "REFUSED" -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A79U      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "DAYS" 2 "WEEKS" 3 "MONTHS"
                       4 "YEARS" 5 "VISITS" 6 "HOURS" ;
label define A79A      -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "MANAGED CARE PLAN"
                       2 "OTHER THIRD PARTY PAYER" 3 "OTHER SPECIFIED" ;
label define A80       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" -5 "MISSING" ;
label define A80B      -9 "INAPPLICABLE, A80 NOT CODED 00000" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO" 1 "YES" ;
label define A81       -9 "INAPPLICABLE, CLIENT TYPE CODED 2" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" 0 "NO CHARGES"
                       1 "FULL AMOUNT BILLED" 2 "SLIDING FEE AMOUNT"
                       3 "REDUCED AMOUNT" 6 "NOT PERMITTED TO ABSTRACT"
                       8 "OTHER" ;
label define A81PC     -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;
label define A82       -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "YES, COMMENTS"
                       2 "NO COMMENTS RECORDED" ;
label define A55OTH    -9 "INAPPLICBALE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "STEROIDS" 2 "POTASSIUM CITRATE"
                       3 "DEPAKOTE" 4 "PROZAC" 5 "PAIN PILLS"
                       6 "STEROID INJECTION (2) CCS" 7 "CHOLONODINE"
                       8 "TEGRETOL" 9 "LITHIUM" 10 "VERAPMIL" 11 "WELLBUTRIN"
                       12 "AMITRIPTYLINE, ELAVIL" 13 "LINSEL" 14 "FLEXERIL"
                       15 "POLYDRUG" 16 "ZOLOFT" 17 "BUSPAR" 18 "NALTREXONE"
                       19 "TRAZODONE" 20 "ZANTAC OR ZANTAX" 21 "PAXIL"
                       22 "LODIENE" 23 "ANXIOLYTICS" 24 "LANAX" 25 "SONA"
                       26 "ANAPROXEN" 27 "HYCEDAL" 28 "SOMA" 29 "ZIAC"
                       30 "SINEQUAN" 31 "FLORCET" 32 "THORAZINE"
                       33 "PREDNISONE" 34 "SERZONE" 35 "ELAVIL"
                       36 "NERVE DRUGS (PILLS)" 37 "ANTABUSE" 38 "PILLS"
                       39 "RISPERDAL" 40 "NAPROXIN" 41 "RX DRUGS"
                       42 "IBUPROFEN, MOTRIN" 43 "TRANQUILIZERS" 44 "HALDOL"
                       45 "DILANTIN" 46 "TRIFILIN" ;
label define A56OTH    -9 "INAPPLICBALE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" 1 "STEROIDS" 2 "POTASSIUM CITRATE"
                       3 "DEPAKOTE" 4 "PROZAC" 5 "PAIN PILLS"
                       6 "STEROID INJECTION (2) CCS" 7 "CHOLONODINE"
                       8 "TEGRETOL" 9 "LITHIUM" 10 "VERAPMIL" 11 "WELLBUTRIN"
                       12 "AMITRIPTYLINE, ELAVIL" 13 "LINSEL" 14 "FLEXERIL"
                       15 "POLYDRUG" 16 "ZOLOFT" 17 "BUSPAR" 18 "NALTREXONE"
                       19 "TRAZODONE" 20 "ZANTAC OR ZANTAX" 21 "PAXIL"
                       22 "LODIENE" 23 "ANXIOLYTICS" 24 "LANAX" 25 "SONA"
                       26 "ANAPROXEN" 27 "HYCEDAL" 28 "SOMA" 29 "ZIAC"
                       30 "SINEQUAN" 31 "FLORCET" 32 "THORAZINE"
                       33 "PREDNISONE" 34 "SERZONE" 35 "ELAVIL"
                       36 "NERVE DRUGS (PILLS)" 37 "ANTABUSE" 38 "PILLS"
                       39 "RISPERDAL" 40 "NAPROXIN" 41 "RX DRUGS"
                       42 "IBUPROFEN, MOTRIN" 43 "TRANQUILIZERS" 44 "HALDOL"
                       45 "DILANTIN" 46 "TRIFILIN" ;
label define AGE_CALC  -5 "MISSING" ;
label define LOS       -5 "MISSING" ;
label define TRT_DUR   -5 "MISSING" ;
label define ALCOHOL   0 "ALCOHOL USE NOT MENTIONED IN CLIENT RECO"
                       1 "ALCOHOL USE MENTIONED IN CLIENT RECORD" ;
label define DRUG      0 "DRUG USE NOT MENTIONED IN CLIENT RECORD"
                       1 "DRUG USE MENTIONED IN CLIENT RECORD" ;
label define DRUG_ALC  1 "ALCOHOL USE ONLY MENTIONED IN CLIENT REC"
                       2 "BOTH ALCOHOL AND DRUG USE MENTIONED IN C"
                       3 "DRUG USE ONLY MENTIONED IN CLIENT RECORD"
                       4 "UNSPEC SUB USE/NO MENTION OF WHICH SUB A" ;
label define PAIR90    1 "A11" 2 "A12" 3 "A13" 4 "A14" 5 "A15" 6 "A16"
                       7 "A21" 8 "A22" 9 "A23" 10 "A24" 11 "A25" 12 "A31"
                       13 "A32" 14 "A33" 15 "A34" 16 "A35" 17 "A36" 18 "A41"
                       19 "A42" 20 "A44" 21 "A45" 22 "A46" 23 "A47" 24 "B01"
                       25 "B02" 26 "B03" 27 "B04" 28 "B05" 29 "B06" 30 "B07"
                       31 "B08" 32 "B09" 33 "B10" 34 "B11" 35 "B12" 36 "B13"
                       37 "C01" 38 "C02" 39 "C04" 40 "C05" 41 "C06" ;
label define CAT_DISC  1 "LESS THAN 33.3RD PERCENTILE" 2 "BETWEEN"
                       3 "GREATER THAN" 33 "RD AND 66.7TH PERCENTILE"
                       67 "TH PERCENTILE" ;
label define CAT_CLI2  1 "0-16" 2 "17-40" 3 "41-100" 4 "101-225" 5 "226+" ;
label define CAT_C_D   1 "LESS THAN 33.3RD PERCENTILE"
                       2 "BETWEEN 33.3RD AND 66.7TH PERCENTILE"
                       3 "GREATER THAN 66.7TH PERCENTILE" ;
label define ABUSE     1 "ALCOHOL" 2 "DRUG" 3 "BOTH" ;
label define TXCARE    1 "M-OUTPATIENT METHADONE"
                       2 "N-OUTPATIENT NON-METHADONE"
                       3 "R-NON-HOSPITAL RESIDENTIAL" ;
label define ABSSMPTY  1 "E-EARLY DROPOUT" 2 "D-MAIN"
                       3 "I-IN TREATMENT METHADONE" ;
label define QFSTRAT   2 "STRATUM 2 RESIDENTIAL"
                       3 "STRATUM 3 PREDOMINANTLY OUTPATIENT METHA"
                       4 "STRATUM 4 OP NON-METH-PREDOMINANTLY ALCO"
                       5 "STRATUM 5 OP NON-METH-NOT IN STRATUM 3 O"
                       6 "STRATUM 6 COMBINATION" ;
label define GROUP     0 "CLIENT TO RECEIVE $15/$10 FOR FOLLOWUP I"
                       1 "CLIENT TO RECEIVE $0/$0 FOR FOLLOWUP INT"
                       2 "CLIENT TO RECEIVE $0/$10 FOR FOLLOWUP IN"
                       3 "CLIENT TO RECEIVE $25/$10 FOR FOLLOWUP I" ;
label define STUDYIND  0 "INCENTIVE STUDY FACILITY" 1 "MAIN STUDY FACILITY" ;
label define PSUTYPE2  1 "METRO CERTAINTY" 2 "METRO NONCERTAINTY"
                       3 "NONMETRO NONCERTAINTY" ;
label define CENREG    1 "NORTHEAST" 2 "MIDWEST" 3 "SOUTH" 4 "WEST" ;
label define OWN       1 "PRIVATE FOR PROFIT" 2 "PRIVATE NONPROFIT"
                       3 "PUBLIC" ;
label define FACTYPE   2 "FACILITY OFFERS RESIDENTIAL TREATMENT ON"
                       3 "FACILITY OFFERS OUTPATIENT METHADONE TRE"
                       4 "FACILITY OFFERS OUTPATIENT NON-METHADONE"
                       5 "FACILITY OFFERS MORE THAN ONE TYPE OF TR" ;
label define A45AGE    -9 "INAPPLICABLE, NEVER USED" -8 "REFUSED"
                       -7 "NOT ASCERTAINED" -6 "DON'T KNOW" ;
label define A69ATD    -9 "INAPPLICABLE" -8 "REFUSED" -7 "NOT ASCERTAINED"
                       -6 "DON'T KNOW" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CASEID = . if (CASEID <= -1 )
replace CLTYPE = . if (CLTYPE <= -1 )
replace COMIN = . if (COMIN <= -1 )
replace A6 = . if (A6 <= -1 )
replace A6A1 = . if (A6A1 <= -1 )
replace A6A2 = . if (A6A2 <= -1 )
replace A6A3 = . if (A6A3 <= -1 )
replace A7 = . if (A7 <= -1 )
replace A9 = . if (A9 <= -1 )
replace A10 = . if (A10 <= -1 )
replace A11 = . if (A11 <= -1 )
replace A14 = . if (A14 <= -1 )
replace A15 = . if (A15 <= -1 )
replace A16 = . if (A16 <= -1 )
replace A17 = . if (A17 <= -1 )
replace A18 = . if (A18 <= -1 )
replace A19 = . if (A19 <= -1 )
replace A20 = . if (A20 <= -1 )
replace A21 = . if (A21 <= -1 )
replace A22 = . if (A22 <= -1 )
replace A23 = . if (A23 <= -1 )
replace A24 = . if (A24 <= -1 )
replace A25 = . if (A25 <= -1 )
replace A26 = . if (A26 <= -1 )
replace A27 = . if (A27 <= -1 )
replace A28 = . if (A28 <= -1 )
replace A29 = . if (A29 <= -1 )
replace A30A = . if (A30A <= -1 )
replace A30B = . if (A30B <= -1 )
replace A30C = . if (A30C <= -1 )
replace A30D = . if (A30D <= -1 )
replace A30E = . if (A30E <= -1 )
replace A30F = . if (A30F <= -1 )
replace A30G = . if (A30G <= -1 )
replace A30H = . if (A30H <= -1 )
replace A30I = . if (A30I <= -1 )
replace A30J = . if (A30J <= -1 )
replace A31 = . if (A31 <= -1 )
replace A32 = . if (A32 <= -1 )
replace A33A = . if (A33A <= -1 )
replace A33B = . if (A33B <= -1 )
replace A33C = . if (A33C <= -1 )
replace A33D = . if (A33D <= -1 )
replace A33E = . if (A33E <= -1 )
replace A33F = . if (A33F <= -1 )
replace A34 = . if (A34 <= -1 )
replace A35 = . if (A35 <= -1 )
replace A36 = . if (A36 <= -1 )
replace A37 = . if (A37 <= -1 )
replace A38 = . if (A38 <= -1 )
replace A39CN = . if (A39CN <= -1 )
replace A39A = . if (A39A <= -1 )
replace A39B = . if (A39B <= -1 )
replace A39C = . if (A39C <= -1 )
replace A39D = . if (A39D <= -1 )
replace A39E = . if (A39E <= -1 )
replace A40EU = . if (A40EU <= -1 )
replace A40LU = . if (A40LU <= -1 )
replace A40AGE = . if (A40AGE <= -1 )
replace A41EU = . if (A41EU <= -1 )
replace A41LU = . if (A41LU <= -1 )
replace A41AGE = . if (A41AGE <= -1 )
replace A42EU = . if (A42EU <= -1 )
replace A42LU = . if (A42LU <= -1 )
replace A42AGE = . if (A42AGE <= -1 )
replace A43EU = . if (A43EU <= -1 )
replace A43LU = . if (A43LU <= -1 )
replace A43AGE = . if (A43AGE <= -1 )
replace A44EU = . if (A44EU <= -1 )
replace A44LU = . if (A44LU <= -1 )
replace A44AGE = . if (A44AGE <= -1 )
replace A45EU = . if (A45EU <= -1 )
replace A45LU = . if (A45LU <= -1 )
replace A46EU = . if (A46EU <= -1 )
replace A46LU = . if (A46LU <= -1 )
replace A46AGE = . if (A46AGE <= -1 )
replace A47EU = . if (A47EU <= -1 )
replace A47LU = . if (A47LU <= -1 )
replace A47AGE = . if (A47AGE <= -1 )
replace A48EU = . if (A48EU <= -1 )
replace A48LU = . if (A48LU <= -1 )
replace A48AGE = . if (A48AGE <= -1 )
replace A49EU = . if (A49EU <= -1 )
replace A49LU = . if (A49LU <= -1 )
replace A49AGE = . if (A49AGE <= -1 )
replace A50EU = . if (A50EU <= -1 )
replace A50LU = . if (A50LU <= -1 )
replace A50AGE = . if (A50AGE <= -1 )
replace A51EU = . if (A51EU <= -1 )
replace A51LU = . if (A51LU <= -1 )
replace A51AGE = . if (A51AGE <= -1 )
replace A52EU = . if (A52EU <= -1 )
replace A52OTH = . if (A52OTH <= -1 )
replace A52LU = . if (A52LU <= -1 )
replace A52AGE = . if (A52AGE <= -1 )
replace A53EU = . if (A53EU <= -1 )
replace A53LU = . if (A53LU <= -1 )
replace A53AGE = . if (A53AGE <= -1 )
replace A54EU = . if (A54EU <= -1 )
replace A54LU = . if (A54LU <= -1 )
replace A54AGE = . if (A54AGE <= -1 )
replace A55EU = . if (A55EU <= -1 )
replace A55LU = . if (A55LU <= -1 )
replace A55AGE = . if (A55AGE <= -1 )
replace A56EU = . if (A56EU <= -1 )
replace A56LU = . if (A56LU <= -1 )
replace A56AGE = . if (A56AGE <= -1 )
replace A57 = . if (A57 <= -1 )
replace A58A = . if (A58A <= -1 )
replace A58B = . if (A58B <= -1 )
replace A58C = . if (A58C <= -1 )
replace A59 = . if (A59 <= -1 )
replace A60A = . if (A60A <= -1 )
replace A60B = . if (A60B <= -1 )
replace A60C = . if (A60C <= -1 )
replace A61 = . if (A61 <= -1 )
replace A62FOP = . if (A62FOP <= -1 )
replace A62FCO = . if (A62FCO <= -1 )
replace A62FTHC = . if (A62FTHC <= -1 )
replace A62FOTH = . if (A62FOTH <= -1 )
replace A62LOP = . if (A62LOP <= -1 )
replace A62LCO = . if (A62LCO <= -1 )
replace A62LTHC = . if (A62LTHC <= -1 )
replace A62LOTH = . if (A62LOTH <= -1 )
replace A63 = . if (A63 <= -1 )
replace A64 = . if (A64 <= -1 )
replace A65 = . if (A65 <= -1 )
replace A65AR = . if (A65AR <= -1 )
replace A65AF = . if (A65AF <= -1 )
replace A65AT = . if (A65AT <= -1 )
replace A65AD = . if (A65AD <= -1 )
replace A65BR = . if (A65BR <= -1 )
replace A65BF = . if (A65BF <= -1 )
replace A65BT = . if (A65BT <= -1 )
replace A65BD = . if (A65BD <= -1 )
replace A65CR = . if (A65CR <= -1 )
replace A65CF = . if (A65CF <= -1 )
replace A65CT = . if (A65CT <= -1 )
replace A65CD = . if (A65CD <= -1 )
replace A65DR = . if (A65DR <= -1 )
replace A65DF = . if (A65DF <= -1 )
replace A65DT = . if (A65DT <= -1 )
replace A65DD = . if (A65DD <= -1 )
replace A65ER = . if (A65ER <= -1 )
replace A65EF = . if (A65EF <= -1 )
replace A65ET = . if (A65ET <= -1 )
replace A65ED = . if (A65ED <= -1 )
replace A65FR = . if (A65FR <= -1 )
replace A65FF = . if (A65FF <= -1 )
replace A65FT = . if (A65FT <= -1 )
replace A65FD = . if (A65FD <= -1 )
replace A65GR = . if (A65GR <= -1 )
replace A65GF = . if (A65GF <= -1 )
replace A65GT = . if (A65GT <= -1 )
replace A65GD = . if (A65GD <= -1 )
replace A65HR = . if (A65HR <= -1 )
replace A65HF = . if (A65HF <= -1 )
replace A65HT = . if (A65HT <= -1 )
replace A65HD = . if (A65HD <= -1 )
replace A65IR = . if (A65IR <= -1 )
replace A65IF = . if (A65IF <= -1 )
replace A65IT = . if (A65IT <= -1 )
replace A65ID = . if (A65ID <= -1 )
replace A65JR = . if (A65JR <= -1 )
replace A65JF = . if (A65JF <= -1 )
replace A65JT = . if (A65JT <= -1 )
replace A65JD = . if (A65JD <= -1 )
replace A66 = . if (A66 <= -1 )
replace A67A = . if (A67A <= -1 )
replace A67AN = . if (A67AN <= -1 )
replace A67B = . if (A67B <= -1 )
replace A67BN = . if (A67BN <= -1 )
replace A67C = . if (A67C <= -1 )
replace A67CN = . if (A67CN <= -1 )
replace A67D = . if (A67D <= -1 )
replace A67DN = . if (A67DN <= -1 )
replace A67E = . if (A67E <= -1 )
replace A67F = . if (A67F <= -1 )
replace A67G = . if (A67G <= -1 )
replace A67H = . if (A67H <= -1 )
replace A67I = . if (A67I <= -1 )
replace A67J = . if (A67J <= -1 )
replace A67K = . if (A67K <= -1 )
replace A67L = . if (A67L <= -1 )
replace A67M = . if (A67M <= -1 )
replace A67N = . if (A67N <= -1 )
replace A67O = . if (A67O <= -1 )
replace A67P = . if (A67P <= -1 )
replace A67Q = . if (A67Q <= -1 )
replace A67R = . if (A67R <= -1 )
replace A67S = . if (A67S <= -1 )
replace A67T = . if (A67T <= -1 )
replace A68 = . if (A68 <= -1 )
replace A68A1 = . if (A68A1 <= -1 )
replace A68A2 = . if (A68A2 <= -1 )
replace A68A3 = . if (A68A3 <= -1 )
replace A69 = . if (A69 <= -1 )
replace A69BTD = . if (A69BTD <= -1 )
replace A69CTD = . if (A69CTD <= -1 )
replace A69DTD = . if (A69DTD <= -1 )
replace A70 = . if (A70 <= -1 )
replace A73 = . if (A73 <= -1 )
replace A74CN = . if (A74CN <= -1 )
replace A74A = . if (A74A <= -1 )
replace A74B = . if (A74B <= -1 )
replace A74C = . if (A74C <= -1 )
replace A74D = . if (A74D <= -1 )
replace A74E = . if (A74E <= -1 )
replace A75 = . if (A75 <= -1 )
replace A75A = . if (A75A <= -1 )
replace A76 = . if (A76 <= -1 )
replace A77 = . if (A77 <= -1 )
replace A77A = . if (A77A <= -1 )
replace A77B = . if (A77B <= -1 )
replace A77C = . if (A77C <= -1 )
replace A77D = . if (A77D <= -1 )
replace A77E = . if (A77E <= -1 )
replace A77F = . if (A77F <= -1 )
replace A77G = . if (A77G <= -1 )
replace A78 = . if (A78 <= -1 )
replace A79 = . if (A79 <= -1 )
replace A79U = . if (A79U <= -1 )
replace A79A = . if (A79A <= -1 )
replace A80 = . if (A80 <= -1 )
replace A80B = . if (A80B <= -1 )
replace A81 = . if (A81 <= -1 )
replace A81PC = . if (A81PC <= -1 )
replace A82 = . if (A82 <= -1 )
replace A55OTH = . if (A55OTH <= -1 )
replace A56OTH = . if (A56OTH <= -1 )
replace AGE_CALC = . if (AGE_CALC <= -1 )
replace LOS = . if (LOS <= -1 )
replace TRT_DUR = . if (TRT_DUR <= -1 )
replace ALCOHOL = . if (ALCOHOL <= -1 )
replace DRUG = . if (DRUG <= -1 )
replace DRUG_ALC = . if (DRUG_ALC <= -1 )
replace PAIR90 = . if (PAIR90 <= -1 )
replace SI_ABS = . if (SI_ABS <= -1.0000 )
replace CST_DISC = . if (CST_DISC <= -1.0000 )
replace CAT_DISC = . if (CAT_DISC <= -1 )
replace CAT_CLI2 = . if (CAT_CLI2 <= -1 )
replace CAT_C_D = . if (CAT_C_D <= -1 )
replace ABUSE = . if (ABUSE <= -1 )
replace ABSUF0 = . if (ABSUF0 <= -1.0000 )
replace ABSCELL3 = . if (ABSCELL3 <= -1 )
replace ABSAF0 = . if (ABSAF0 <= -1 )
replace TXCARE = . if (TXCARE <= -1 )
replace A2TWT1 = . if (A2TWT1 <= -1.0000 )
replace A2TWT2 = . if (A2TWT2 <= -1.0000 )
replace A2TWT3 = . if (A2TWT3 <= -1.0000 )
replace A2TWT4 = . if (A2TWT4 <= -1.0000 )
replace A2TWT5 = . if (A2TWT5 <= -1.0000 )
replace A2TWT6 = . if (A2TWT6 <= -1.0000 )
replace A2TWT7 = . if (A2TWT7 <= -1.0000 )
replace A2TWT8 = . if (A2TWT8 <= -1.0000 )
replace A2TWT9 = . if (A2TWT9 <= -1.0000 )
replace A2TWT10 = . if (A2TWT10 <= -1.0000 )
replace A2TWT11 = . if (A2TWT11 <= -1.0000 )
replace A2TWT12 = . if (A2TWT12 <= -1.0000 )
replace A2TWT13 = . if (A2TWT13 <= -1.0000 )
replace A2TWT14 = . if (A2TWT14 <= -1.0000 )
replace A2TWT15 = . if (A2TWT15 <= -1.0000 )
replace A2TWT16 = . if (A2TWT16 <= -1.0000 )
replace A2TWT17 = . if (A2TWT17 <= -1.0000 )
replace A2TWT18 = . if (A2TWT18 <= -1.0000 )
replace A2TWT19 = . if (A2TWT19 <= -1.0000 )
replace A2TWT20 = . if (A2TWT20 <= -1.0000 )
replace A2TWT21 = . if (A2TWT21 <= -1.0000 )
replace A2TWT22 = . if (A2TWT22 <= -1.0000 )
replace A2TWT23 = . if (A2TWT23 <= -1.0000 )
replace A2TWT24 = . if (A2TWT24 <= -1.0000 )
replace A2TWT25 = . if (A2TWT25 <= -1.0000 )
replace A2TWT26 = . if (A2TWT26 <= -1.0000 )
replace A2TWT27 = . if (A2TWT27 <= -1.0000 )
replace A2TWT28 = . if (A2TWT28 <= -1.0000 )
replace A2TWT29 = . if (A2TWT29 <= -1.0000 )
replace A2TWT30 = . if (A2TWT30 <= -1.0000 )
replace A2TWT31 = . if (A2TWT31 <= -1.0000 )
replace A2TWT32 = . if (A2TWT32 <= -1.0000 )
replace A2TWT33 = . if (A2TWT33 <= -1.0000 )
replace A2TWT34 = . if (A2TWT34 <= -1.0000 )
replace A2TWT35 = . if (A2TWT35 <= -1.0000 )
replace A2TWT36 = . if (A2TWT36 <= -1.0000 )
replace A2TWT37 = . if (A2TWT37 <= -1.0000 )
replace A2TWT38 = . if (A2TWT38 <= -1.0000 )
replace A2TWT39 = . if (A2TWT39 <= -1.0000 )
replace A2TWT40 = . if (A2TWT40 <= -1.0000 )
replace A2TWT41 = . if (A2TWT41 <= -1.0000 )
replace A2TWT42 = . if (A2TWT42 <= -1.0000 )
replace A2TWT43 = . if (A2TWT43 <= -1.0000 )
replace A2TWT44 = . if (A2TWT44 <= -1.0000 )
replace A2TWT45 = . if (A2TWT45 <= -1.0000 )
replace A2TWT46 = . if (A2TWT46 <= -1.0000 )
replace A2TWT47 = . if (A2TWT47 <= -1.0000 )
replace A2TWT48 = . if (A2TWT48 <= -1.0000 )
replace A2TWT49 = . if (A2TWT49 <= -1.0000 )
replace A2TWT50 = . if (A2TWT50 <= -1.0000 )
replace A2TWT51 = . if (A2TWT51 <= -1.0000 )
replace A2TWT52 = . if (A2TWT52 <= -1.0000 )
replace A2TWT53 = . if (A2TWT53 <= -1.0000 )
replace A2TWT54 = . if (A2TWT54 <= -1.0000 )
replace A2TWT55 = . if (A2TWT55 <= -1.0000 )
replace A2TWT56 = . if (A2TWT56 <= -1.0000 )
replace A2TWT57 = . if (A2TWT57 <= -1.0000 )
replace A2TWT58 = . if (A2TWT58 <= -1.0000 )
replace A2TWT59 = . if (A2TWT59 <= -1.0000 )
replace A2TWT60 = . if (A2TWT60 <= -1.0000 )
replace A2TWT61 = . if (A2TWT61 <= -1.0000 )
replace A2TWT62 = . if (A2TWT62 <= -1.0000 )
replace A2TWT63 = . if (A2TWT63 <= -1.0000 )
replace A2TWT64 = . if (A2TWT64 <= -1.0000 )
replace A2TWT65 = . if (A2TWT65 <= -1.0000 )
replace A2TWT66 = . if (A2TWT66 <= -1.0000 )
replace A2TWT67 = . if (A2TWT67 <= -1.0000 )
replace A2TWT68 = . if (A2TWT68 <= -1.0000 )
replace A2TWT69 = . if (A2TWT69 <= -1.0000 )
replace A2TWT70 = . if (A2TWT70 <= -1.0000 )
replace A2TWT71 = . if (A2TWT71 <= -1.0000 )
replace A2TWT72 = . if (A2TWT72 <= -1.0000 )
replace A2TWT73 = . if (A2TWT73 <= -1.0000 )
replace A2TWT74 = . if (A2TWT74 <= -1.0000 )
replace A2TWT75 = . if (A2TWT75 <= -1.0000 )
replace A2TWT76 = . if (A2TWT76 <= -1.0000 )
replace A2TWT77 = . if (A2TWT77 <= -1.0000 )
replace A2TWT78 = . if (A2TWT78 <= -1.0000 )
replace ATRMFCTR = . if (ATRMFCTR <= -1.0000 )
replace ABSSMPTY = . if (ABSSMPTY <= -1 )
replace QFSTRAT = . if (QFSTRAT <= -1 )
replace GROUP = . if (GROUP <= -1 )
replace STUDYIND = . if (STUDYIND <= -1 )
replace FIELDPSU = . if (FIELDPSU <= -1 )
replace PSUTYPE2 = . if (PSUTYPE2 <= -1 )
replace CENREG = . if (CENREG <= -1 )
replace OWN = . if (OWN <= -1 )
replace FACTYPE = . if (FACTYPE <= -1 )
replace A2BWT0 = . if (A2BWT0 <= -1.0000 )
replace A2TWT0 = . if (A2TWT0 <= -1.0000 )
replace ASMPCNT = . if (ASMPCNT <= -1 )
replace F2FWA0 = . if (F2FWA0 <= -1.0000 )
replace VST_PSU = . if (VST_PSU <= -1 )
replace VUN_PSU = . if (VUN_PSU <= -1 )
replace A45AGE = . if (A45AGE <= -1 )
replace A69ATD = . if (A69ATD <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

